@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 use Path::Tiny qw( path );
 use Path::Tiny::Rule;
@@ -81,7 +81,8 @@ sub _new_precious_toml {
             lint_flags              => '--check',
             tidy_flags              => '--in-place',
             ok_exit_codes           => 0,
-            lint_failure_exit_codes => 1
+            lint_failure_exit_codes => 1,
+            expect_stderr           => 'true',
         },
         'commands.podchecker' => {
             type          => 'lint',
@@ -111,7 +112,8 @@ sub _new_precious_toml {
             lint_flags    => '--check',
             tidy_flags    => '--in-place',
             ok_exit_codes => 0,
-            lint_failure_exit_codes => 1
+            lint_failure_exit_codes => 1,
+            expect_stderr           => 'true',
         };
     }
 
@@ -240,7 +242,7 @@ Dist::Zilla::Plugin::DROLSKY::Precious - Creates a default precious.toml file if
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =for Pod::Coverage .*
 
